/* global BDF */

/**
 * Objet définissant un ensemble de collections ordonnées de façon arborescente
 * 
 * @constructor
 */
BDF.SubsetTrees = function () {
    this.subsetTreeMap = null;
    this.patternArrayMap = null;
 /* subsetMap est un tableau associés d'instances d'objets subset
 * où la clé du tableau est celle du corpus ou du thésaurus
 */
    this.subsetMap = new Object();
};

/**
 * 
 * @param {string} category
 * @returns {configuration?json=subset-tree}
 */
BDF.SubsetTrees.prototype.getSubsetTree = function (category) {
    return this.subsetTreeMap[category];
};

/*
 * 
 * @param {string} subsetKeyString
 * @returns {Object}
 */
BDF.SubsetTrees.prototype.getSubset = function (subsetKey) {
    if (this.subsetMap.hasOwnProperty(subsetKey)) {
        return this.subsetMap[subsetKey];
    } else {
        return null;
    }
};

/**
 * 
 * @param {string} patternType
 * @returns {main?json=availablepatterns}
 */
BDF.SubsetTrees.prototype.getPatternArray = function (patternType) {
    if (this.patternArrayMap.hasOwnProperty(patternType)) {
        return this.patternArrayMap[patternType];
    } else {
        return null;
    }
};

BDF.SubsetTrees.load = function (callback) {
    var subsetTrees = new BDF.SubsetTrees(new Object());
    BDF.Ajax.loadPatternArrayMap(function (patternArrayMap) {
        subsetTrees.patternArrayMap = patternArrayMap;
        BDF.Ajax.loadSubsetTreeMap("corpus,thesaurus,album,addenda,sphere", 1, function (subsetTreeMap) {
            subsetTrees.subsetTreeMap = subsetTreeMap;
            _buildMap("corpus", subsetTreeMap["corpus"]);
            _buildMap("thesaurus", subsetTreeMap["thesaurus"]);
            _buildMap("album", subsetTreeMap["album"]);
            _buildMap("addenda", subsetTreeMap["addenda"]);
            _buildMap("sphere", subsetTreeMap["sphere"]);
            callback(subsetTrees);
        });
    });
    
    function _buildMap(category, nodeArray) {
        var length = nodeArray.length;
        for(var i = 0; i < length; i++) {
            var obj = nodeArray[i];
            var nodeType = obj.node;
            if (nodeType === "subset") {
                _completeSubset(obj, category);
                subsetTrees.subsetMap[obj.key] = obj;
            } else if (nodeType === "group") {
                _buildMap(category, obj.array);
            }
        }
    }
    
    function _completeSubset(subsetObj, category) {
        subsetObj.category = category;
        subsetObj.generatedId = BDF.generateId();
        for(let detailName in subsetObj.details) {
            let detailArray = subsetObj.details[detailName];
            for(let detail of detailArray) {
                detail.patternArray = subsetTrees.getPatternArray(detail.patternType);
                detail.withPatterns = ((detail.patternArray) && (detail.patternArray.length > 0));
                detail.generatedId = BDF.generateId();
                detail.cmSpanArray = BDF.parseCmSpanArray(detail.key);
            }
        }
    }

};
