/* global BdfApi */

/**
 * Objet de configuration de l'accès à une fichothèque
 * L'objet options permet de conserver des options avec l'objet
 * 
 * @constructor
 * @param {string} fichothequeUrl URL de la fichothèque (doit être fini par un /)
 * @param {Object} options Options conservées par la configuration
  */
BdfApi.Config = function (fichothequeUrl, options) {
    this.fichothequeUrl = fichothequeUrl;
    this.options = {};
    if (options) {
        for(var key in options) {
            this.options[key] = options[key];
        }
    }
};


/**
 * Retourne l'URL corresponant à une action sur une fichothèque
 * 
 * @param {string} actionName Nom de l'action
 * @returns {string} URL de l'action
 */
BdfApi.Config.prototype.getActionUrl = function (actionName) {
    return this.fichothequeUrl + actionName;
};


/**
 * Retourne l'URL de consultation d'une fiche
 * 
 * @param {string} corpus Nom du corpus
 * @param {number} id Identifiant de la fiche
 * @param {string} [format] Nom du gabarit d'affichage à utiliser
 * @returns {string} URL de la fiche
 */
BdfApi.Config.prototype.getFicheUrl = function (corpus, id, format) {
    var url = this.fichothequeUrl + "fiches/" + corpus + "-" + id;
    if (format) {
        url += "-" + format;
    }
    url = url + ".html";
    return url;
};
